%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%    Writing data for all strips to file for post processing %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all

%% Parameters
ha = 7.83;
ka = 0.105;
steep_1 = 0.02;
steep = 1/steep_1;

if ka == 0.105
    Tper = 2.021;
elseif ka == 0.127
    Tper = 1.732;
elseif ka == 0.163
    Tper = 1.443;
elseif ka == 0.388
    Tper = 0.866;
elseif ka == 0.290
    Tper = 1.010;
elseif ka == 0.229
    Tper = 1.155;
elseif ka == 0.190
    Tper = 1.299;
elseif ka == 0.142
    Tper = 1.588;
elseif ka == 0.115
    Tper = 1.876;
elseif ka == 0.097
    Tper = 2.165;
elseif ka == 0.090
    Tper = 2.309;
else 
    disp('Invalid ka number');
end

%% Constants
scale = 48;
d = 6.9/scale;
aa = d/2;
h = ha*aa;
rho = 1000;

%% Probes properties
n = 100;                  %number of radial probes
Nc = 160;                   %integration point around cylinder
probeline = [1:Nc];       %probeline vector
[dl theta rd] = probes();    %length and angle for probelines
delta_s = (pi*d)/Nc;      %element length

%% Strips                     
M_max = 10;
m = [1:1:M_max];

%% Locate files
pth0 = ['Stokes_waves/ha',num2str(ha),'/ka',num2str(ka),'/steep',num2str(steep_1),'/']; 
% 
%% Write to file for strip m
for i = 1:length(m)
[F_int wdudz] = writeToFile(pth0,m(i),Nc,probeline,n,h,Tper,steep,dl,theta,delta_s,M_max,rd,aa,rho);
end

%Function for computing Fx, Fy and F2D for strip m
function [F_int wdudz] = writeToFile(pth0,m,Nc,probeline,n,h,Tper,steep,dl,theta,delta_s,M_max,rd,aa,rho)
%% Strips 1...m
        pth1 = [pth0 'plane',num2str(m-1),'/'];
        pth2 = [pth0 'plane',num2str(m),'/'];
  
        z_1 = readZ(pth1);
        z_2 = readZ(pth2);
        mid_z = (z_2 + z_1)/2;
        delta_z = abs(z_2 - z_1);
    
        for i = 1:Nc
            [u_1 time] = readProbes(pth1,probeline(i),n);
            [u_2 time_2] = readProbes(pth2,probeline(i),n);
            [w_2_1 u_2_1 k_stokes] = stokes5thWavesMiddleStrip(h,Tper,steep,mid_z,time);
             wdudz = (w_2_1)'.*(u_2+u_1)/delta_z;
            
            %Pressure
                u_r = u_2_1*(1 - (aa/rd)^2)*cos(theta(i));
                u_theta = -u_2_1*(1 - (aa/rd)^2)*sin(theta(i));
                p_rd = 0.5*(u_r.^2 + u_theta.^2);
                
    
            for j = 1:length(time)    
                     
                %Force integration
                F_int(i,j) = trapz(wdudz(:,j),dl(i,:));
                pw(i,j) = p_rd(i) - F_int(i,j);
                Fx(i,j) = pw(i,j)*delta_s*cos(theta(i));
                Fy(i,j) = pw(i,j)*delta_s*sin(theta(i));
                Fw(j) = sum(Fx(:,j)) + sum(Fy(:,j));
             
            end
            
        end
        
        [F2D_1 time] = readCFDForce(pth1);
        [F2D_2 time_2] = readCFDForce(pth2);
        
         F2D = (F2D_1 + F2D_2)/2;

        
     kcdir = ['Strips/strip' num2str(m,'%i') '/']
     pth_file = [pth0 kcdir];
     [SUCCESS,MESSAGE,MESSAGEID] = mkdir(pth_file);
     
     file_vector = [ time' ; Fw ];
     filename = [pth_file 'Fw.txt'];
     fid = fopen(filename,'w');
     fprintf(fid,'%f %f\r\n',file_vector);
     fclose(fid);
    
     filename = [pth_file 'delta_z.txt'];
     fid = fopen(filename,'w');
     fprintf(fid,'%f\r\n',delta_z);
     fprintf(fid,'%f\r\n',z_1);
     fprintf(fid,'%f\r\n',z_2);
     fclose(fid);
%     
     F2D_vector = [ time' ; F2D'];
     filename = [pth_file '2D_force.txt'];
     fid = fopen(filename,'w');
     fprintf(fid,'%f % f\r\n',F2D_vector);
     fclose(fid);

end

function z = readZ(pth)

fname = [pth 'z.txt'];
fid = fopen(fname, 'r');
if (fid == -1)
    error('FFL:fopen', 'Unable to open: %s', fname);
end

dataRaw = fscanf(fid, '%f');
z = dataRaw(1,1);

fclose(fid);

end

function [w u k] = stokes5thWavesMiddleStrip(h,T,steep,z_strip,t)


g = 9.81;                % Gravity constant [m/s^2]

x = 0;                     % x-coordinate [m]
Ntper = 50;               % Discretization of wave period [no]

%% Angular velocity 
omega = 2*pi/T;
    
 %% Compute wave number k and parameter gamma
kw1 = findk(T,h);
za1 = pi/(kw1*steep);
H   = 2*za1;%Hm(iper);
k = kw1;
za = za1;

gamma = k*za;

%% Compute Skjelbreia constants
[A11 A13 A15 A22 A24 A33 A35 A44 A55 B22 B24 B33 B35 B44 B55 C1 C2 C3 C4] ...
     = computeSkjelbreiaConstants(k,h);
 
%% Coefficients for velocity potential and surface profile
D1 = omega/k^2*(gamma*A11 + gamma^3*A13 + gamma^5*A15);
D2 = omega/k^2*(gamma^2*A22 + gamma^4*A24);
D3 = omega/k^2*(gamma^3*A33 + gamma^5*A35);
D4 = omega/k^2*(gamma^4*A44);
D5 = omega/k^2*(gamma^5*A55);

E1 = gamma;
E2 = gamma^2*B22 + gamma^4*B24;
E3 = gamma^3*B33 + gamma^5*B35;
E4 = gamma^4*B44; 
E5 = gamma^5*B55;

%% Phase angle
th  = k*x - omega*t;

%% Surface profile
  zeta = 1/k*(E1*cos(th) + ...
    E2*cos(2*th) + ...
    E3*cos(3*th) + ...
    E4*cos(4*th) + ...
    E5*cos(5*th));

%% Wave celerity C
C0 = g*(tanh(k*h));
C = ((g*tanh(h*k)*(C2*gamma^4 + C1*gamma^2 + 1))/k)^(1/2);

if z_strip <= 0
%% Velocities, acceleration and velocity gradients for z <= 0
[u,w,dudt,dudx,dudz] = computeVelocities(omega,k,g,h,x, ...
    D1,D2,D3,D4,D5,E1,E2,E3,E4,E5,C,z_strip,t);
elseif z_strip >= 0
[u,w,dudt,dudx,dudz] = taylorExpansion(omega,k,h,D1,D2,D3, ...
    D4,D5,C,x,z_strip,t);
end

end

